==> diffprivlib-0.1.1.tar.gz: diffprivlib-0.1.1/diffprivlib/mechanisms/transforms/roundedinteger.py <==
# MIT License
#
# Copyright (C) IBM Corporation 2019
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
# documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit
# persons to whom the Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
# Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""
Rounded integer transformer. Rounds the output of the given mechanism to the nearest integer.
"""
from diffprivlib.mechanisms.transforms.base import DPTransformer


class RoundedInteger(DPTransformer):
    """
    Rounded integer transform. Rounds the (float) output of the given mechanism to the nearest integer.
    """
    def post_transform(self, value):
        """
        Transforms the mechanism output to the nearest integer.

        :param value: Mechanism output value to be transformed.
        :type value: `float`
        :return: Transformed mechanism output.
        :rtype: `int`
        """
        return int(round(value))

==> diffprivlib-0.1.2.tar.gz: diffprivlib-0.1.2/diffprivlib/mechanisms/transforms/roundedinteger.py <==
# MIT License
#
# Copyright (C) IBM Corporation 2019
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
# documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit
# persons to whom the Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
# Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""
Rounded integer transformer. Rounds the output of the given mechanism to the nearest integer.
"""
from diffprivlib.mechanisms.transforms.base import DPTransformer


class RoundedInteger(DPTransformer):
    """
    Rounded integer transform. Rounds the (float) output of the given mechanism to the nearest integer.
    """
    def post_transform(self, value):
        """Transforms the (float) output of the mechanism to be a rounded integer.

        Parameters
        ----------
        value : float
            Mechanism output to be transformed.

        Returns
        -------
        int
            Transformed output value.

        """
        return int(round(value))
